@@ -25,7 +25,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 require XSLoader;
 XSLoader::load('Email::AddressParser', $VERSION);
@@ -45,6 +45,13 @@ sub phrase
    return $this->{personal};
 }
 
+sub original
+{
+   my $this = shift;
+
+   return $this->format;
+}
+
 sub address
 {
    my $this = shift;
